@@ -33,30 +33,30 @@ sleep_event = threading.Event()
 shutdown_event = threading.Event()
 
 
-ready_msg = r"""
+ready_msg = r'''
  ____  _____    _    ______   __
 |  _ \| ____|  / \  |  _ \ \ / /
 | |_) |  _|   / _ \ | | | \ V / 
 |  _ <| |___ / ___ \| |_| || |  
 |_| \_\_____/_/   \_\____/ |_|                                  
-"""
+'''
 
-crash_msg = r"""
+crash_msg = r'''
   ____ ____      _    ____  _   _ 
  / ___|  _ \    / \  / ___|| | | |
 | |   | |_) |  / _ \ \___ \| |_| |
 | |___|  _ <  / ___ \ ___) |  _  |
  \____|_| \_\/_/   \_\____/|_| |_|
-"""
+'''
 
-dead_msg = r"""
+dead_msg = r'''
  ____  _____    _    ____         __
 |  _ \| ____|  / \  |  _ \   _   / /
 | | | |  _|   / _ \ | | | | (_) | | 
 | |_| | |___ / ___ \| |_| |  _  | | 
 |____/|_____/_/   \_\____/  (_) | | 
                                  \_\
-"""
+'''
 
 
 def validate_token(oauth_token):
